@@ -14,10 +14,10 @@ def test_binary_metrics(t):
     y_true = np.array([1, 1, 1, 0, 0, 0])
     y_pred = np.array([.9, .9, 1., .9, .1, .1])
 
-    score_df = binary_metrics(y_true, y_pred, threshold=t)
+    score = binary_metrics(y_true, y_pred, threshold=t)
 
     pred_label = np.where(y_pred > t, 1, 0)
-    assert score_df.loc['accuracy_score']['score'] == accuracy_score(y_true, pred_label)
+    assert score.get('accuracy_score') == accuracy_score(y_true, pred_label)
 
 
 def test_regression_metrics():
